scoretools.get_previous_measure_from_component
==============================================

.. autofunction:: abjad.tools.scoretools.get_previous_measure_from_component.get_previous_measure_from_component
